@@ -1,5 +1,5 @@
 // ASResource.cpp
-// Copyright (c) 2024 The Artistic Style Authors.
+// Copyright (c) 2025 The Artistic Style Authors.
 // This code is licensed under the MIT License.
 // License.md describes the conditions under which this software may be distributed.
 
@@ -503,9 +503,9 @@ void ASResource::buildOperators(std::vector<const std::string*>* operators, int
 		operators->emplace_back(&AS_EQUAL_JS);
 	}
 	if (fileType == SHARP_TYPE)
-    {
-    	operators->emplace_back(&AS_COALESCE_CS);
-    }
+	{
+		operators->emplace_back(&AS_COALESCE_CS);
+	}
 	assert(operators->size() < elements);
 	sort(operators->begin(), operators->end(), sortOnLength);
 }
@@ -732,8 +732,8 @@ std::string_view ASBase::getCurrentWord(std::string_view line, size_t index) con
 	for (i = index; i < lineLength; i++)
 	{
 		if (!isLegalNameChar(line[i])
-			|| ( (isCStyle() || isJavaStyle()) && i > index && line[i]=='.')
-			)
+		        || ( (isCStyle() || isJavaStyle()) && i > index && line[i] == '.')
+		   )
 			break;
 	}
 	return line.substr(index, i - index);
@@ -742,13 +742,13 @@ std::string_view ASBase::getCurrentWord(std::string_view line, size_t index) con
 // check if a specific character can be used in a legal variable/method/class name
 bool ASBase::isLegalNameChar(char ch) const
 {
-	if (isWhiteSpace(ch))
+	if (std::isblank(ch))
 		return false;
 	if ((unsigned char) ch > 127)
 		return false;
 	return (isalnum((unsigned char) ch)
-            || ch == '_'
-            || (!isSharpStyle() && ch == '.' )
+	        || ch == '_'
+	        || (!isSharpStyle() && ch == '.' )
 	        || (isJavaStyle() && ch == '$')
 	        || (isSharpStyle() && ch == '@'));  // may be used as a prefix
 }
@@ -756,7 +756,7 @@ bool ASBase::isLegalNameChar(char ch) const
 // check if a specific character can be part of a header
 bool ASBase::isCharPotentialHeader(std::string_view line, size_t i) const
 {
-	assert(!isWhiteSpace(line[i]));
+	assert(!std::isblank(line[i]));
 	char prevCh = ' ';
 	if (i > 0)
 		prevCh = line[i - 1];
@@ -770,7 +770,7 @@ bool ASBase::isCharPotentialHeader(std::string_view line, size_t i) const
 // check if a specific character can be part of an operator
 bool ASBase::isCharPotentialOperator(char ch) const
 {
-	assert(!isWhiteSpace(ch));
+	assert(!std::isblank(ch));
 	if ((unsigned) ch > 127)
 		return false;
 	return (ispunct((unsigned char) ch)
