@@ -1,11 +1,16 @@
 // astyle.h
-// Copyright (c) 2024 The Artistic Style Authors.
+// Copyright (c) 2025 The Artistic Style Authors.
 // This code is licensed under the MIT License.
 // License.md describes the conditions under which this software may be distributed.
 
 #ifndef ASTYLE_H
 #define ASTYLE_H
 
+// ignore size_t to int conversion warning for now
+#ifdef _WIN64
+	#pragma warning( disable : 4267 )
+#endif
+
 //-----------------------------------------------------------------------------
 // headers
 //-----------------------------------------------------------------------------
@@ -23,7 +28,7 @@
 	#include <cstring>              // need both string and cstring for GCC
 #endif
 
-#define ASTYLE_VERSION "3.6.4"
+#define ASTYLE_VERSION "3.6.7"
 
 namespace astyle {
 
@@ -291,8 +296,6 @@ protected:  // inline functions
 	bool isObjCStyle() const { return baseFileType == OBJC_TYPE; }
 	bool isGSCStyle() const { return baseFileType == GSC_TYPE; }
 
-	bool isWhiteSpace(char ch) const { return (ch == ' ' || ch == '\t'); }
-
 protected:  // functions definitions are at the end of ASResource.cpp
 	const std::string* findHeader(std::string_view line, int i,
 	                              const std::vector<const std::string*>* possibleHeaders) const;
@@ -353,6 +356,7 @@ public:
 	void setPreprocDefineIndent(bool state);
 	void setPreprocConditionalIndent(bool state);
 	void setSqueezeWhitespace(bool state);
+	void setPreserveWhitespace(bool state);
 	void setLambdaIndentation(bool state);
 	int  getBeautifierFileType() const;
 	int  getFileType() const;
@@ -403,6 +407,7 @@ protected:
 	bool isInIndentableStruct;
 	bool isInIndentablePreproc;
 	bool lambdaIndicator;
+	bool preserveWhitespace;
 
 
 private:  // functions
@@ -443,13 +448,13 @@ private:  // functions
 	std::vector<std::vector<const std::string*>*>* copyTempStacks(const ASBeautifier& other) const;
 	std::pair<int, int> computePreprocessorIndent();
 
-	bool handleHeaderSection(std::string_view line, size_t *i, bool closingBraceReached, bool *haveCaseIndent);
-	bool handleColonSection(std::string_view line, size_t *i, bool tabIncrementIn, char *ch);
-	void handleEndOfStatement(size_t i, bool *closingBraceReached, char *ch);
+	bool handleHeaderSection(std::string_view line, size_t* i, bool closingBraceReached, bool *haveCaseIndent);
+	bool handleColonSection(std::string_view line, size_t* i, bool tabIncrementIn, char* ch);
+	void handleEndOfStatement(size_t i, bool *closingBraceReached, char* ch);
 	void handleParens(std::string_view line, size_t i, bool tabIncrementIn, bool * isInOperator, char ch);
 	void handleClosingParen(std::string_view line, size_t i, bool tabIncrementIn);
-	void handlePotentialHeaderSection(std::string_view line, size_t *i, bool tabIncrementIn, bool *isInOperator);
-	void handlePotentialOperatorSection(std::string_view line, size_t i, bool tabIncrementIn, bool haveAssignmentThisLine, bool isInOperator);
+	void handlePotentialHeaderSection(std::string_view line, size_t* i, bool tabIncrementIn, bool *isInOperator);
+	void handlePotentialOperatorSection(std::string_view line, size_t* i, bool tabIncrementIn, bool haveAssignmentThisLine, bool isInOperator);
 
 
 private:  // variables
@@ -552,6 +557,7 @@ private:  // variables
 	bool shouldAlignMethodColon;
 	bool shouldIndentPreprocConditional;
 	bool squeezeWhitespace;
+
 	bool attemptLambdaIndentation;
 
 	bool isInAssignment;
@@ -681,9 +687,9 @@ public:	// functions
 	void init(ASSourceIterator* si) override;
 
 	bool hasMoreLines() const;
-        void extracted();
-        std::string nextLine();
-        LineEndFormat getLineEndFormat() const;
+	void extracted();
+	std::string nextLine();
+	LineEndFormat getLineEndFormat() const;
 	bool getIsLineReady() const;
 	void setFormattingStyle(FormatStyle style);
 	void setAddBracesMode(bool state);
@@ -876,11 +882,11 @@ private:  // functions
 	void handleClosedBracesOrParens();
 	void handleBraces();
 	void handleBreakLine();
-	bool handlePotentialHeader(const std::string *);
+	bool handlePotentialHeader(const std::string*);
 	void handleEndOfBlock();
 	void handleColonSection();
 	void handlePotentialHeaderPart2();
-	void handlePotentialOperator(const std::string *);
+	void handlePotentialOperator(const std::string*);
 	void handleParens();
 	void handleOpenParens();
 
@@ -931,7 +937,7 @@ private:  // variables
 	int  templateDepth;
 	int  squareBracketCount;
 	int  parenthesesCount;
-	int  closingBracesCount;
+	int  bracesNestingLevel;
 	size_t  squeezeEmptyLineNum;
 	size_t  squeezeEmptyLineCount;
 
@@ -1132,7 +1138,7 @@ private:  // inline functions
 	// check if a specific sequence exists in the current placement of the current line
 	bool isSequenceReached(std::string_view sequence) const
 	{
-    	return currentLine.compare(charNum, sequence.length(), sequence) == 0;
+		return currentLine.compare(charNum, sequence.length(), sequence) == 0;
 	}
 
 	// call ASBase::findHeader for the current character
